codon_at_ref_pos

Function codon_at_ref_pos 

fn codon_at_ref_pos(
    gapped_query: &[u8],
    gapped_ref: &[u8],
    ref_start: usize,
    ref_pos: usize,
) -> Option<[u8; 3]>
Collect 3 consecutive non-deleted query bases at reference positions ref_pos..ref_pos+3. Returns None if the position is outside the aligned region or any of the 3 ref positions has a deletion in the query (consistent with the existing policy of skipping frameshifts).